import bpy

# Define a new operator that adds a passive rigid body and sets the dynamic property to False
class AddPassiveRigidBody(bpy.types.Operator):
    bl_idname = "object.add_passive_rigid_body"
    bl_label = "Add Passive Rigid Body"

    def execute(self, context):
        # Add a passive rigid body to the selected object
        bpy.ops.rigidbody.objects_add(type='PASSIVE')
        return {'FINISHED'}

    
class VIEW3D_PT_QuickRigid(bpy.types.Panel):
    bl_idname = "OBJECT_PT_my_panel"
    bl_label = "Quick Rigid"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_category = "Quick Rigid"
   
    def draw(self, context): 
        if bpy.context.selected_objects == []:
            layout = self.layout
            row = layout.row()
            row.label(text="Select a mesh to add a rigid body")
            
            
        obj = bpy.context.active_object
        # Check if a object is selected then check if it's a mesh
        if obj and obj.type == 'MESH' and obj.select_get():
            
            
            layout = self.layout
            row = layout.row()
            layout.scale_y = 1.15
            row.operator("rigidbody.object_add", text="Add Active")  # Example using the 'PHYSICS' icon
            # Call the new operator from the panel
            row.operator("object.add_passive_rigid_body", text="Add Passive")
        
            
            active_object = bpy.context.active_object
            # display the type of rigid body
            if active_object.rigid_body is not None:
                row = layout.row() 
                if active_object.rigid_body.type == 'PASSIVE':
                    row.label(text="Type: Passive", icon='INFO')
                elif active_object.rigid_body.type == 'ACTIVE':
                    row.label(text="Type: Active", icon='INFO')
            else:
                row = layout.row()
                row.label(text="No Rigid Body", icon="CANCEL")

            if obj and obj.rigid_body:
            
                # Adding the "Remove Riged Body" button
                row = layout.row() 
                row.operator("rigidbody.object_remove", text="Remove Rigid Body")
                
                # Add the collision shape dropdown menu
                row = layout.row()
                row.prop(context.object.rigid_body, "collision_shape", text="Shape")
                
                # Adding the mass slidbar to my pannel
                row = layout.row()
                row.prop(obj.rigid_body, "kinematic", toggle=True, text="Animated", icon="RENDER_ANIMATION")
                            
                row = layout.row()
                row.operator("rigidbody.object_settings_copy", text="Copy from active", icon="COPYDOWN")
                
                # Box around the Mass options
                box = layout.box()
                box.label(text="Mass:")
                row = box.row()
                row.use_property_decorate = True
                row.prop(obj.rigid_body, "mass", slider=False)

                row = box.row()
                row.operator("rigidbody.mass_calculate", text="Calculate mass from volume")


                # Box around Surface Response
                box = layout.box()
                box.label(text="Surface Response:")
                row = box.row()
                row.prop(obj.rigid_body, "friction", toggle=True, text="Friction")
                row = box.row()
                row.prop(obj.rigid_body, "restitution", toggle=True, text="Bounciness")

                # Box around the Gravity
                box = layout.box()
                row_gravity_checkbox = box.row()
                col_gravity_checkbox = row_gravity_checkbox.column()
                # Adding the gravity Sliders
                col_gravity_checkbox.prop(bpy.context.scene, "use_gravity", text="Gravity")

                row_gravity_xyz = box.row()
                col_gravity_xyz = row_gravity_xyz.column()
                col_gravity_xyz.use_property_decorate = False
                col_gravity_xyz.use_property_split = True

                if bpy.context.scene.use_gravity:
                    col_gravity_xyz.prop(bpy.context.scene, "gravity", text="Gravity")
                else:
                    col_gravity_xyz.prop(bpy.context.scene, "gravity", text="Gravity")
                    col_gravity_xyz.enabled = False

                row_sim_speed = box.row()
                # Sim
                row_sim_speed.prop(context.scene.rigidbody_world, 'time_scale', text="Sim Speed")
                bpy.context.scene.use_gravity
                
                # Box around the Bake
                box = layout.box()

                box.label(text="Bake:")

                row = box.row()
                row.operator("rigidbody.bake_to_keyframes", text="Bake to keyframes")
            
        elif obj and obj.type != 'MESH' and obj.select_get():
            layout = self.layout
            row = layout.row()
            row.label(text="Select a mesh to add a rigid body")


# if __name__ == "__main__":
#     register()